==> tgp_2.1-2.tar.gz: tgp/demo/cat.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(maptree)
#options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 2: 
###################################################
fb.train <- fried.bool(500)
X <- fb.train[,1:13]; Z <- fb.train$Y
fb.test <- fried.bool(1000)
XX <- fb.test[,1:13]; ZZ <- fb.test$Ytrue


###################################################
### chunk number 3: 
###################################################
names(X)


###################################################
### chunk number 4: 
###################################################
fit1 <- bcart(X=X, Z=Z, XX=XX, m0r1=TRUE, verb=0)
rmse1 <- sqrt(mean((fit1$ZZ.mean - ZZ)^2))
rmse1


###################################################
### chunk number 5: cat-fbcart-mapt
###################################################
tgp.trees(fit1, "map")


###################################################
### chunk number 6: 
###################################################
fit2 <- btlm(X=X, Z=Z, XX=XX, m0r1=TRUE, verb=0)
rmse2 <- sqrt(mean((fit2$ZZ.mean - ZZ)^2))
rmse2


###################################################
### chunk number 7: cat-fbtlm-trees
###################################################
tgp.trees(fit2, "map")


###################################################
### chunk number 8: 
###################################################
fit3 <- btlm(X=X, Z=Z, XX=XX, basemax=10, m0r1=TRUE, verb=0)
rmse3 <- sqrt(mean((fit3$ZZ.mean - ZZ)^2))
rmse3


###################################################
### chunk number 9: cat-fbtlm-mapt
###################################################
tgp.trees(fit3, "map")


###################################################
### chunk number 10: 
###################################################
fit4 <- btgpllm(X=X, Z=Z, XX=XX, m0r1=TRUE, verb=0)
rmse4 <- sqrt(mean((fit4$ZZ.mean - ZZ)^2))
rmse4


###################################################
### chunk number 11: 
###################################################
fit4$gpcs


###################################################
### chunk number 12: 
###################################################
fit5 <-  btgpllm(X=X, Z=Z, XX=XX, m0r1=TRUE, basemax=10, verb=0)
rmse5 <- sqrt(mean((fit5$ZZ.mean - ZZ)^2))
rmse5 


###################################################
### chunk number 13: cat-fb-mapt
###################################################
h <- fit1$post$height[which.max(fit1$posts$lpost)]
tgp.trees(fit5, "map")


###################################################
### chunk number 14: 
###################################################
fit6 <-  btgpllm(X=X, Z=Z, XX=XX, m0r1=TRUE, basemax=10, 
                 splitmin=11, verb=0)
rmse6 <- sqrt(mean((fit6$ZZ.mean - ZZ)^2))
rmse6

==> tgp_2.1-3.tar.gz: tgp/demo/cat.R <==
###################################################
### chunk number 1: 
###################################################
library(tgp)
library(maptree)
#options(width=65)
seed <- 0; set.seed(seed)


###################################################
### chunk number 2: 
###################################################
fb.train <- fried.bool(500)
X <- fb.train[,1:13]; Z <- fb.train$Y
fb.test <- fried.bool(1000)
XX <- fb.test[,1:13]; ZZ <- fb.test$Ytrue


###################################################
### chunk number 3: 
###################################################
names(X)


###################################################
### chunk number 4: 
###################################################
fit1 <- bcart(X=X, Z=Z, XX=XX, verb=0)
rmse1 <- sqrt(mean((fit1$ZZ.mean - ZZ)^2))
rmse1


###################################################
### chunk number 5: cat-fbcart-mapt
###################################################
tgp.trees(fit1, "map")


###################################################
### chunk number 6: 
###################################################
fit2 <- btlm(X=X, Z=Z, XX=XX, verb=0)
rmse2 <- sqrt(mean((fit2$ZZ.mean - ZZ)^2))
rmse2


###################################################
### chunk number 7: cat-fbtlm-trees
###################################################
tgp.trees(fit2, "map")


###################################################
### chunk number 8: 
###################################################
fit3 <- btlm(X=X, Z=Z, XX=XX, basemax=10, verb=0)
rmse3 <- sqrt(mean((fit3$ZZ.mean - ZZ)^2))
rmse3


###################################################
### chunk number 9: cat-fbtlm-mapt
###################################################
tgp.trees(fit3, "map")


###################################################
### chunk number 10: 
###################################################
fit4 <- btgpllm(X=X, Z=Z, XX=XX, verb=0)
rmse4 <- sqrt(mean((fit4$ZZ.mean - ZZ)^2))
rmse4


###################################################
### chunk number 11: 
###################################################
fit4$gpcs


###################################################
### chunk number 12: 
###################################################
fit5 <-  btgpllm(X=X, Z=Z, XX=XX, basemax=10, verb=0)
rmse5 <- sqrt(mean((fit5$ZZ.mean - ZZ)^2))
rmse5 


###################################################
### chunk number 13: cat-fb-mapt
###################################################
h <- fit1$post$height[which.max(fit1$posts$lpost)]
tgp.trees(fit5, "map")


###################################################
### chunk number 14: 
###################################################
fit6 <-  btgpllm(X=X, Z=Z, XX=XX, basemax=10, 
                 splitmin=11, verb=0)
rmse6 <- sqrt(mean((fit6$ZZ.mean - ZZ)^2))
rmse6
